| Title: | Convert Nested Functions to Pipes |
|---|---|
| Description: | To take nested function calls and convert them to a more readable form using pipes from package 'magrittr'. |
| Authors: | Houston R Users, Neeraj Tandon, Ed Goodwin, Ju Yeong Kim, Sahil Seth |
| Maintainer: | Sahil Seth <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-15 10:19:52 UTC |
| Source: | https://github.com/cran/pipefittr |
make_list
make_list(string)make_list(string)
string |
a string to be converted into a list |
make_output
make_output(funclist)make_output(funclist)
funclist |
a list of functions |
To take nested function calls and convert them to a more readable form using magrittr's pipes.
pipefittr(string, pretty = F)pipefittr(string, pretty = F)
string |
a string, to be converted into |
pretty |
create a multiline output, which is prettier. Try this. |
teststring = "jump_on(bop_on( scoop_up( hop_through(foo_foo, forest), field_mouse ), head))" pipefittr(teststring, pretty = TRUE)teststring = "jump_on(bop_on( scoop_up( hop_through(foo_foo, forest), field_mouse ), head))" pipefittr(teststring, pretty = TRUE)
Splits list into a data.frame
splitlisttodf(listtosplit)splitlisttodf(listtosplit)
listtosplit |
a list to be converted into a data.frame |
Splits string into a list
splitmultistrtolist(stringtosplit)splitmultistrtolist(stringtosplit)
stringtosplit |
a string to be split |